@@ -331,6 +331,11 @@ struct _EvJobPageDataClass
 	EvJobClass parent_class;
 };
 
+typedef enum {
+        EV_JOB_THUMBNAIL_PIXBUF,
+        EV_JOB_THUMBNAIL_SURFACE
+} EvJobThumbnailFormat;
+
 struct _EvJobThumbnail
 {
 	EvJob parent;
@@ -338,9 +343,14 @@ struct _EvJobThumbnail
 	gint page;
 	gint rotation;
 	gdouble scale;
+	gint target_width;
+	gint target_height;
 
 	GdkPixbuf *thumbnail;
         gboolean has_frame;
+
+        EvJobThumbnailFormat format;
+        cairo_surface_t *thumbnail_surface;
 };
 
 struct _EvJobThumbnailClass
@@ -534,8 +544,15 @@ EvJob          *ev_job_thumbnail_new           (EvDocument      *document,
                                                 gint             page,
                                                 gint             rotation,
                                                 gdouble          scale);
+EvJob	       *ev_job_thumbnail_new_with_target_size (EvDocument      *document,
+						       gint		page,
+						       gint		rotation,
+						       gint		target_width,
+						       gint		target_height);
 void            ev_job_thumbnail_set_has_frame (EvJobThumbnail  *job,
                                                 gboolean         has_frame);
+void            ev_job_thumbnail_set_output_format (EvJobThumbnail      *job,
+                                                    EvJobThumbnailFormat format);
 /* EvJobFonts */
 GType 		ev_job_fonts_get_type 	  (void) G_GNUC_CONST;
 EvJob 	       *ev_job_fonts_new 	  (EvDocument      *document);
