@@ -130,6 +130,7 @@ ev_sidebar_annotations_add_annots_list (EvSidebarAnnotations *ev_annots)
 	/* Create tree view */
 	loading_model = ev_sidebar_annotations_create_simple_model (_("Loading…"));
 	ev_annots->priv->tree_view = gtk_tree_view_new_with_model (loading_model);
+	gtk_widget_set_margin_top (ev_annots->priv->tree_view, 2);
 	g_object_unref (loading_model);
 
 	gtk_tree_view_set_headers_visible (GTK_TREE_VIEW (ev_annots->priv->tree_view),
@@ -196,12 +197,17 @@ ev_sidebar_annotations_add_annots_palette (EvSidebarAnnotations *ev_annots)
 					     GTK_SHADOW_IN);
 
 	ev_annots->priv->palette = gtk_tool_palette_new ();
+	gtk_widget_set_margin_top (ev_annots->priv->palette, 2);
+	gtk_widget_set_margin_bottom (ev_annots->priv->palette, 2);
+	gtk_widget_set_margin_start (ev_annots->priv->palette, 2);
+	gtk_widget_set_margin_end (ev_annots->priv->palette, 2);
+
 	group = gtk_tool_item_group_new (_("Annotations"));
+	gtk_tool_item_group_set_header_relief (GTK_TOOL_ITEM_GROUP (group), GTK_RELIEF_NONE);
 	gtk_container_add (GTK_CONTAINER (ev_annots->priv->palette), group);
 
-	/* FIXME: use a better icon than EDIT */
 	item = gtk_toggle_tool_button_new ();
-	gtk_tool_button_set_icon_name (GTK_TOOL_BUTTON (item), GTK_STOCK_EDIT);
+	gtk_tool_button_set_icon_name (GTK_TOOL_BUTTON (item), "document-new-symbolic");
 	gtk_tool_button_set_label (GTK_TOOL_BUTTON (item), _("Text"));
 	gtk_widget_set_tooltip_text (GTK_WIDGET (item), _("Add text annotation"));
 	ev_annots->priv->annot_text_item = item;
@@ -359,6 +365,9 @@ job_finished_callback (EvJobAnnots          *job,
 	GList *l;
 	GdkPixbuf *text_icon = NULL;
 	GdkPixbuf *attachment_icon = NULL;
+        GdkPixbuf *highlight_icon = NULL;
+        GdkPixbuf *strike_out_icon = NULL;
+        GdkPixbuf *underline_icon = NULL;
 
 	priv = sidebar_annots->priv;
 
@@ -441,7 +450,36 @@ job_finished_callback (EvJobAnnots          *job,
                                                                                          GTK_ICON_SIZE_BUTTON);
 				}
 				pixbuf = attachment_icon;
-			}
+			} else if (EV_IS_ANNOTATION_TEXT_MARKUP (annot)) {
+                                switch (ev_annotation_text_markup_get_markup_type (EV_ANNOTATION_TEXT_MARKUP (annot))) {
+                                case EV_ANNOTATION_TEXT_MARKUP_HIGHLIGHT:
+                                        if (!highlight_icon) {
+                                                /* FIXME: use better icon than select all */
+                                                highlight_icon = gtk_widget_render_icon_pixbuf (priv->tree_view,
+                                                                                                GTK_STOCK_SELECT_ALL,
+                                                                                                GTK_ICON_SIZE_BUTTON);
+                                        }
+                                        pixbuf = highlight_icon;
+
+                                        break;
+                                case EV_ANNOTATION_TEXT_MARKUP_STRIKE_OUT:
+                                        if (!strike_out_icon) {
+                                                strike_out_icon = gtk_widget_render_icon_pixbuf (priv->tree_view,
+                                                                                                 GTK_STOCK_STRIKETHROUGH,
+                                                                                                 GTK_ICON_SIZE_BUTTON);
+                                        }
+                                        pixbuf = strike_out_icon;
+                                        break;
+                                case EV_ANNOTATION_TEXT_MARKUP_UNDERLINE:
+                                        if (!underline_icon) {
+                                                underline_icon = gtk_widget_render_icon_pixbuf (priv->tree_view,
+                                                                                                GTK_STOCK_UNDERLINE,
+                                                                                                GTK_ICON_SIZE_BUTTON);
+                                        }
+                                        pixbuf = underline_icon;
+                                        break;
+                                }
+                        }
 
 			gtk_tree_store_append (model, &child_iter, &iter);
 			gtk_tree_store_set (model, &child_iter,
@@ -465,6 +503,12 @@ job_finished_callback (EvJobAnnots          *job,
 		g_object_unref (text_icon);
 	if (attachment_icon)
 		g_object_unref (attachment_icon);
+        if (highlight_icon)
+                g_object_unref (highlight_icon);
+        if (strike_out_icon)
+                g_object_unref (strike_out_icon);
+        if (underline_icon)
+                g_object_unref (underline_icon);
 
 	g_object_unref (job);
 	priv->job = NULL;
